#ifndef __OBJECT_PROPERTIES_H__
#define __OBJECT_PROPERTIES_H__

/**
 * \brief  Basic object style dialog
 *
 * Authors:
 *   Lauris Kaplinski <lauris@ximian.com>
 *   Frank Felfe <iname@innerspace.com>
 *
 * Copyright (C) 2000-2001 Lauris Kaplinski and Frank Felfe
 * Copyright (C) 2001-2002 Ximian, Inc. and Lauris Kaplinski
 *
 * Released under GNU GPL
 */

void sp_object_properties_dialog            (void);

void sp_object_properties_fill              (void);
void sp_object_properties_stroke            (void);
void sp_object_properties_stroke_style   (void);

#endif

/*
  Local Variables:
  mode:c++
  c-file-style:"stroustrup"
  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
  indent-tabs-mode:nil
  fill-column:99
  End:
*/
// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
